import { AwsCredentialIdentity, ParsedIniData } from "@smithy/types";
import { ProcessCredentials } from "./ProcessCredentials";
/**
 * @internal
 */
export declare const getValidatedProcessCredentials: (profileName: string, data: ProcessCredentials, profiles: ParsedIniData) => AwsCredentialIdentity;
