import {
  CredentialProviderOptions,
  RuntimeConfigAwsCredentialIdentityProvider,
} from "@aws-sdk/types";
import { SourceProfileInit } from "@smithy/shared-ini-file-loader";
export interface FromProcessInit
  extends SourceProfileInit,
    CredentialProviderOptions {}
export declare const fromProcess: (
  init?: FromProcessInit
) => RuntimeConfigAwsCredentialIdentityProvider;
