export type ProcessCredentials = {
  Version: number;
  AccessKeyId: string;
  SecretAccessKey: string;
  SessionToken?: string;
  Expiration?: number;
  CredentialScope?: string;
  AccountId?: string;
};
