import { AwsCredentialIdentity, Logger, ParsedIniData } from "@smithy/types";
/**
 * @internal
 */
export declare const resolveProcessCredentials: (profileName: string, profiles: ParsedIniData, logger?: Logger) => Promise<AwsCredentialIdentity>;
